==> spine_client-0.2.0.tar.gz: lib/web_firebase_client.dart <==
/*
 * Copyright 2019, TeamDev. All rights reserved.
 *
 * Redistribution and use in source and/or binary forms, with or without
 * modification, must retain the above copyright notice and the following
 * disclaimer.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import 'package:firebase/firebase.dart' as fb;
import 'package:spine_client/firebase_client.dart';

/// An implementation of [FirebaseClient] specific to browser JavaScript.
///
/// See `RestClient` for a platform-agnostic implementation.
///
class WebFirebaseClient implements FirebaseClient {

    final fb.Database _db;

    WebFirebaseClient(this._db);

    @override
    Stream<String> get(String path) async* {
        yield* _db
            .ref(path)
            .onChildAdded
            .map(_toJsonString);
    }

    @override
    Stream<String> childAdded(String path) {
        return _db
            .ref(path)
            .onChildAdded
            .map(_toJsonString);
    }

    @override
    Stream<String> childChanged(String path) {
        return _db
            .ref(path)
            .onChildChanged
            .map(_toJsonString);
    }

    @override
    Stream<String> childRemoved(String path) {
        return _db
            .ref(path)
            .onChildRemoved
            .map(_toJsonString);
    }

    String _toJsonString(event) {
        return event.snapshot.toJson().toString();
    }
}

==> spine_client-0.2.2.tar.gz: lib/web_firebase_client.dart <==
/*
 * Copyright 2020, TeamDev. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Redistribution and use in source and/or binary forms, with or without
 * modification, must retain the above copyright notice and the following
 * disclaimer.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import 'package:firebase/firebase.dart' as fb;
import 'package:spine_client/firebase_client.dart';

/// An implementation of [FirebaseClient] specific to browser JavaScript.
///
/// See `RestClient` for a platform-agnostic implementation.
///
class WebFirebaseClient implements FirebaseClient {

    final fb.Database _db;

    WebFirebaseClient(this._db);

    @override
    Stream<String> get(String path) {
        return childAdded(path);
    }

    @override
    Stream<String> childAdded(String path) {
        return _db
            .ref(path)
            .onChildAdded
            .map(_toJsonString);
    }

    @override
    Stream<String> childChanged(String path) {
        return _db
            .ref(path)
            .onChildChanged
            .map(_toJsonString);
    }

    @override
    Stream<String> childRemoved(String path) {
        return _db
            .ref(path)
            .onChildRemoved
            .map(_toJsonString);
    }

    String _toJsonString(event) {
        return event.snapshot.toJson().toString();
    }
}
